#include <dos.h>
#include <stdlib.h>
#include <stdio.h>
#include <time.h>
#include <string.h>
#include <math.h>

#define    IN_BUF_SIZE      1024
#define    NoError          0
#define    InitPinIsOpen    0
#define    InitPinIsNotOpen 1
#define    QueueIsEmpty     0
#define    QueueIsNotEmpty  1
#define    PortError       -1
#define    DataError       -2
#define    ParityError     -3
#define    StopError       -4
#define    TimeOut         -5
#define    QueueEmpty      -6
#define    QueueOverflow   -7
#define    PosError        -8
#define    AddrError       -9
#define    BlockError      -10
#define    WriteError      -11
#define    SegmentError    -12
#define    BaudRateError   -13
#define    CheckSumError   -14
#define    ChannelError    -15
#define    TimeIsUp        1

void InitLib(void);
int  InstallCom(int port, unsigned long baud, int data, int parity, int stop);
int  InstallCom1(unsigned long baud, int data, int parity, int stop);
int  InstallCom2(unsigned long baud, int data, int parity, int stop);
int  InstallCom3(unsigned long baud, int data, int parity);
int  InstallCom4(unsigned long baud, int data, int parity);
int  RestoreCom(int port);
int  RestoreCom1(void);
int  RestoreCom2(void);
int  RestoreCom3(void);
int  RestoreCom4(void);
int  IsCom(int port);
int  IsCom1(void);
int  IsCom2(void);
int  IsCom3(void);
int  IsCom4(void);
int  ReadCom(int port);
int  ReadCom1(void);
int  ReadCom2(void);
int  ReadCom3(void);
int  ReadCom4(void);
int  ToCom(int port, int data);
int  ToCom1(int data);
int  ToCom2(int data);
int  ToCom3(int data);
int  ToCom4(int data);
int  ToComStr(int port, char *str);
int  ToCom1Str(char *str);
int  ToCom2Str(char *str);
int  ToCom3Str(char *str);
int  ToCom4Str(char *str);
int  ClearCom(int port);
int  ClearCom1(void);
int  ClearCom2(void);
int  ClearCom3(void);
int  ClearCom4(void);
int  WaitTransmitOver(int port);
int  WaitTransmitOver1(void);
int  WaitTransmitOver2(void);
int  WaitTransmitOver3(void);
int  WaitTransmitOver4(void);
int  Set485DirToTransmit(int port);
int  Set485DirToReceive(int port);

int  ReadInitPin(void);
void LedOff(void);
void LedOn(void);
void Init5DigitLed(void);
int  Show5DigitLed(int position, int value);
int  Show5DigitLedSeg(int pos, unsigned char data);
void DelayTimeMs(unsigned int time);

int  ReadNVRAM(int addr);
int  WriteNVRAM(int addr, int data);
void WriteRTC(int subaddr,int data);
void ReadRTC(int subaddr,int *data);

int  WriteEEP(int block, int addr, int data);
int  ReadEEP(int block, int addr);
void EnableEEP(void);
void ProtectEEP(void);

void EnableWDT(void);
void RefreshWDT(void);
void DisableWDT(void);

int FlashReadId(void);
int FlashWrite(unsigned int seg, unsigned int offset, char data);
int FlashErase(unsigned int seg);
int FlashRead(unsigned int seg, unsigned int offset);

void Delay(unsigned ms);
void Delay_1(unsigned ms);

int getch4(void);
int kbhit4(void);
int ungetch4(int key);
void putch4(int data);

char hex_to_ascii(int iHex);
int ascii_to_hex(char ascii);
int SendCmdTo9000(int iPort, unsigned char *cCmd, int iChksum);
int ReceiveResponseFrom9000(int iPort, unsigned char *cCmd, long lTimeout, int iChksum);

void far *_MK_FP(unsigned segment,unsigned offset);
int IsResetByWatchDogTimer(void);
int IsResetByPowerOff(void); /* for bios date 12/12/98 or later */

int Show5DigitLedWithDot(int pos, int data);
void Set5DigitLedTestMode(int mode);
void Set5DigitLedIntensity(int mode);
void Disable5DigitLed(void);
void Enable5DigitLed(void);
unsigned GetLibVersion(void);

int TimerOpen(void);
int TimerClose(void);
void TimerResetValue(void);
unsigned long TimerReadValue(void);
void DelayMs(unsigned t);
int StopWatchReset(int channel);
int StopWatchStart(int channel);
int StopWatchStop(int channel);
int StopWatchPause(int channel);
int StopWatchContinue(int channel);
int StopWatchReadValue(int channel,unsigned long *value);
int CountDownTimerStart(int channel,unsigned long count);
int CountDownTimerReadValue(int channel,unsigned long *value);
void InstallUserTimer(void (*fun)(void));
void InstallUserTimer1C(void (*fun)(void));
int IsCom3OutBufEmpty(void);
int IsCom4OutBufEmpty(void);
int DataSizeInCom(int port);
int DataSizeInCom1(void);
int DataSizeInCom2(void);
int DataSizeInCom3(void);
int DataSizeInCom4(void);

void SetDtrActive(void);
void SetDtrInactive(void);
void SetRtsActive(void);
void SetRtsInactive(void);

